Welcome to bruges's documentation!
==================================
.. include:: source/intro.rst

.. include:: source/status.rst

.. include:: source/install.rst

Content
-------

.. toctree::
   :caption: Table of Contents
   :name: mastertoc

   Home <source/intro>
   Install <source/install>    
   API <api/api_toc>
   Contributors <../contributors>
   Links <source/links>
   Index <source/indices>

.. include:: ../contributors.rst

.. include:: source/links.rst

.. include:: source/indices.rst

